/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 09043
 |          POLICY RESEARCH ON AGING AND MENTAL HEALTH SERVICES
 |                            (PRAMHS) PROJECT
 |                 (DATASET 0002: AREA AGENCIES ON AGING)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\09043-0002-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE caseid    1='(1) Unique sequential id' 349='(349) Unique sequential id' ;
  VALUE v5ffffff  1='(1) Alabama' 2='(2) Alaska' 3='(3) Arizona' 4='(4) Arkansas'
                  5='(5) California' 6='(6) Colorado' 7='(7) Connecticut' 8='(8) Delaware'
                  9='(9) District of Columbia' 10='(10) Florida' 11='(11) Georgia'
                  12='(12) Hawaii' 13='(13) Idaho' 14='(14) Illinois' 15='(15) Indiana' 16='(16) Iowa'
                  17='(17) Kansas' 18='(18) Kentucky' 19='(19) Louisiana' 20='(20) Maine'
                  21='(21) Maryland' 22='(22) Massachusetts' 23='(23) Michigan'
                  24='(24) Minnesota' 25='(25) Mississippi' 26='(26) Missouri' 27='(27) Montana'
                  28='(28) Nebraska' 29='(29) Nevada' 30='(30) New Hampshire'
                  31='(31) New Jersey' 32='(32) New Mexico' 33='(33) New York'
                  34='(34) North Carolina' 35='(35) North Dakota' 36='(36) Ohio'
                  37='(37) Oklahoma' 38='(38) Oregon' 39='(39) Pennsylvania'
                  40='(40) Rhode Island' 41='(41) South Carolina' 42='(42) South Dakota'
                  43='(43) Tennessee' 44='(44) Texas' 45='(45) Utah' 46='(46) Vermont'
                  47='(47) Virginia' 48='(48) Washington' 49='(49) West Virginia'
                  50='(50) Wisconsin' 51='(51) Wyoming' 52='(52) American Samoa' 53='(53) Guam'
                  54='(54) Puerto Rico' 55='(55) Virgin Islands' 56='(56) Marianna Islands'
                  57='(57) North Marianna Islands' ;
  VALUE v6ffffff  1='(1) Area agency on aging' 2='(2) State unit on aging'
                  3='(3) Community mental health centers'
                  4='(4) State mental health agency' ;
  VALUE v7ffffff  2='(2) Agency 2' 602='(602) Agency 602' ;
  VALUE v8ffffff  0='(0) Less than one year' 15='(15) Fifteen years' 99='(99) N/A' ;
  VALUE v9ffffff  1='(1) Private non-profit' 2='(2) Regional planning body' 3='(3) Other'
                  9='(9) N/A' ;
  VALUE v10fffff  0='(0) None' 52456='(52456) Thousand dollars' 99999='(99999) N/A' ;
  VALUE v11fffff  0='(0) None' 5300='(5300) Thousand dollars' 9999='(9999) N/A' ;
  VALUE v12fffff  0='(0) None' 33='(33) Thirty three percent' 99='(99) N/A' ;
  VALUE v13fffff  0='(0) None' 99='(99) Number of full-time professional staff'
                  999='(999) N/A' ;
  VALUE v14fffff  0='(0) None' 99='(99) Number of part-time professional staff'
                  999='(999) N/A' ;
  VALUE v15fffff  0='(0) None' 85='(85) Number of full-time support staff' 99='(99) N/A' ;
  VALUE v16fffff  0='(0) None' 99='(99) Number of part-time support staff' 999='(999) N/A' ;
  VALUE v17fffff  0='(0) None' 99='(99) Number of volunteers' 999='(999) N/A' ;
  VALUE v18fffff  0='(0) None' 99='(99) Ninety nine percent' 999='(999) N/A' ;
  VALUE v19fffff  0='(0) None' 99='(99) Ninety nine percent' 999='(999) N/A' ;
  VALUE v20fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v21fffff  0='(0) None' 99='(99) Ninety nine percent' 999='(999) N/A' ;
  VALUE v22fffff  0='(0) None' 99='(99) Ninety nine percent' 999='(999) N/A' ;
  VALUE v23fffff  0='(0) None' 99='(99) Ninety nine percent' 999='(999) N/A' ;
  VALUE v24fffff  0='(0) None' 99='(99) Ninety nine percent' 999='(999) N/A' ;
  VALUE v25fffff  0='(0) None' 99='(99) Ninety nine percent' 999='(999) N/A' ;
  VALUE v26fffff  0='(0) None' 99='(99) Ninety nine percent' 999='(999) N/A' ;
  VALUE v27fffff  0='(0) None' 99='(99) Ninety nine percent' 999='(999) N/A' ;
  VALUE v28fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v29fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v30fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v31fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v32fffff  1='(1) No contact' 2='(2) Less often' 3='(3) Monthly' 4='(4) Weekly'
                  9='(9) N/A' ;
  VALUE v33fffff  1='(1) No involvement' 2='(2) Information' 3='(3) Review/comment'
                  4='(4) Joint planning session' 9='(9) N/A' ;
  VALUE v34fffff  1='(1) No involvement' 2='(2) Information' 3='(3) Review/comment'
                  4='(4) Joint planning session' 9='(9) N/A' ;
  VALUE v35fffff  1='(1) CMHC' 2='(2) Private clinic' 3='(3) Public hospital'
                  4='(4) Private hospital' 7='(7) Checked more than one' 9='(9) N/A' ;
  VALUE v36fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v37fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v38fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v39fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v40fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v41fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v42fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v43fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v44fffff  1='(1) Not at all' 2='(2) Limited extent' 3='(3) Moderate extent'
                  4='(4) Great extent' 9='(9) N/A' ;
  VALUE v45fffff  1='(1) Not responsive' 2='(2) Moderately responsive'
                  3='(3) Very responsive' 9='(9) N/A' ;
  VALUE v46fffff  1='(1) None' 2='(2) Public hearings' 3='(3) Lobbying'
                  4='(4) Advocacy groups-formal organizations'
                  5='(5) Needs assessment' 6='(6) Other' 9='(9) N/A' ;
  VALUE v47fffff  1='(1) Informal, personal relations'
                  2='(2) Attitudes, awareness, interest'
                  3='(3) Knowledge and information' 4='(4) Stability-turnover'
                  5='(5) Time and resources-mismanagement' 6='(6) Training' 9='(9) N/A' ;
  VALUE v48fffff  1='(1) Informal, personal relations'
                  2='(2) Attitudes, awareness, interest'
                  3='(3) Knowledge and information' 4='(4) Stability-turnover'
                  5='(5) Time and resources-mismanagement' 6='(6) Training' 9='(9) N/A' ;
  VALUE v49fffff  1='(1) Informal, personal relations'
                  2='(2) Attitudes, awareness, interest'
                  3='(3) Knowledge and information' 4='(4) Stability-turnover'
                  5='(5) Time and resources-mismanagement' 6='(6) Training' 9='(9) N/A' ;
  VALUE v50fffff  1='(1) Funding sources differ'
                  2='(2) Lack of resources-mismanagement'
                  3='(3) Contract for services' 4='(4) OAA does not fund MH services'
                  9='(9) N/A' ;
  VALUE v51fffff  1='(1) Funding sources differ'
                  2='(2) Lack of resources-mismanagement'
                  3='(3) Contract for services' 4='(4) OAA does not fund MH services'
                  9='(9) N/A' ;
  VALUE v52fffff  1='(1) Funding sources differ'
                  2='(2) Lack of resources-mismanagement'
                  3='(3) Contract for services' 4='(4) OAA does not fund MH services'
                  9='(9) N/A' ;
  VALUE v53fffff  1='(1) Medical Model vs. Social Service Model'
                  2='(2) Higher level decisions' 3='(3) Confidentiality'
                  4='(4) MH lack of outreach'
                  5='(5) Either MH or elderly not priority'
                  6='(6) Good intentions-anticipated' 9='(9) N/A' ;
  VALUE v54fffff  1='(1) Medical Model vs. Social Service Model'
                  2='(2) Higher level decisions' 3='(3) Confidentiality'
                  4='(4) MH lack of outreach'
                  5='(5) Either MH or elderly not priority'
                  6='(6) Good intentions-anticipated' 9='(9) N/A' ;
  VALUE v55fffff  1='(1) Medical Model vs. Social Service Model'
                  2='(2) Higher level decisions' 3='(3) Confidentiality'
                  4='(4) MH lack of outreach'
                  5='(5) Either MH or elderly not priority'
                  6='(6) Good intentions-anticipated' 9='(9) N/A' ;
  VALUE v56fffff  1='(1) Communications (contact) not routine'
                  2='(2) Organization Competition' 3='(3) Formal linkages'
                  4='(4) Newness of agency' 5='(5) Proximity, co-location'
                  6='(6) Other (agency closed CMHC)' 9='(9) N/A' ;
  VALUE v57fffff  1='(1) Communications (contact) not routine'
                  2='(2) Organization Competition' 3='(3) Formal linkages'
                  4='(4) Newness of agency' 5='(5) Proximity, co-location'
                  6='(6) Other (agency closed CMHC)' 9='(9) N/A' ;
  VALUE v58fffff  1='(1) Communications (contact) not routine'
                  2='(2) Organization Competition' 3='(3) Formal linkages'
                  4='(4) Newness of agency' 5='(5) Proximity, co-location'
                  6='(6) Other (agency closed CMHC)' 9='(9) N/A' ;
  VALUE v59fffff  1='(1) Stigma of mental illness' 2='(2) Stigma of elderly'
                  3='(3) Elderly powerless and unorganized'
                  4='(4) Other (community disinterest in MH prog' 9='(9) N/A' ;
  VALUE v60fffff  1='(1) Stigma of mental illness' 2='(2) Stigma of elderly'
                  3='(3) Elderly powerless and unorganized'
                  4='(4) Other (community disinterest in MH prog' 9='(9) N/A' ;
  VALUE v61fffff  1='(1) Stigma of mental illness' 2='(2) Stigma of elderly'
                  3='(3) Elderly powerless and unorganized'
                  4='(4) Other (community disinterest in MH prog' 9='(9) N/A' ;
  VALUE v62fffff  1='(1) Yes/no' 2='(2) No/no' 3='(3) Yes/yes' 9='(9) N/A' ;
  VALUE v63fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered not at all'
                  5='(5) Both answered to a limited extent'
                  6='(6) Both answered to a moderate extent'
                  7='(7) Both answered to a great extent' 9='(9) N/A' ;
  VALUE v64fffff  1='(1) Yes/no' 2='(2) No/no' 3='(3) Yes/yes' 9='(9) N/A' ;
  VALUE v65fffff  1='(1) Incongruent by 2' 2='(2) Incongruent by 1'
                  3='(3) Both answered not at all'
                  4='(4) Both answered moderately responsive'
                  5='(5) Both answered very responsive' 9='(9) N/A' ;
  VALUE v66fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered no contact'
                  5='(5) Both answered less than monthly'
                  6='(6) Both answered monthly' 7='(7) Both answered weekly' 9='(9) N/A' ;
  VALUE v67fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered no involvement'
                  5='(5) Both answered information'
                  6='(6) Both answered review and comment'
                  7='(7) Both answered joint planning sessions' 9='(9) N/A' ;
  VALUE v68fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered no involvement'
                  5='(5) Both answered information'
                  6='(6) Both answered review and comment'
                  7='(7) Both answered joint planning sessions' 9='(9) N/A' ;
  VALUE v69fffff  0='(0) None' 9='(9) Nine agencies' 99='(99) N/A' ;
  VALUE v70fffff  1='(1) CMHC, Mental Health Institute'
                  2='(2) Hospital (general, state and mental)'
                  3='(3) Social/community agencies'
                  4='(4) Local, county government agencies' 5='(5) Advocacy agencies'
                  6='(6) Planning agencies' 7='(7) Other (undefined agencies)'
                  9='(9) N/A' ;
  VALUE v71fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v72fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v73fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v74fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v75fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v76fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v77fffff  1='(1) CMHC, Mental Health Institute'
                  2='(2) Hospital (general, state and mental)'
                  3='(3) Social/community agencies'
                  4='(4) Local, county government agencies' 5='(5) Advocacy agencies'
                  6='(6) Planning agencies' 7='(7) Other (undefined agencies)'
                  9='(9) N/A' ;
  VALUE v78fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v79fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v80fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v81fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v82fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v83fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v84fffff  1='(1) CMHC, Mental Health Institute'
                  2='(2) Hospital (general, state and mental)'
                  3='(3) Social/community agencies'
                  4='(4) Local, county government agencies' 5='(5) Advocacy agencies'
                  6='(6) Planning agencies' 7='(7) Other (undefined agencies)'
                  9='(9) N/A' ;
  VALUE v85fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v86fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v87fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v88fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v89fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v90fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v91fffff  1='(1) CMHC, Mental Health Institute'
                  2='(2) Hospital (general, state and mental)'
                  3='(3) Social/community agencies'
                  4='(4) Local, county government agencies' 5='(5) Advocacy agencies'
                  6='(6) Planning agencies' 7='(7) Other (undefined agencies)'
                  9='(9) N/A' ;
  VALUE v92fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v93fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v94fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v95fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v96fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v97fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v98fffff  1='(1) CMHC, Mental Health Institute'
                  2='(2) Hospital (general, state and mental)'
                  3='(3) Social/community agencies'
                  4='(4) Local, county government agencies' 5='(5) Advocacy agencies'
                  6='(6) Planning agencies' 7='(7) Other (undefined agencies)'
                  9='(9) N/A' ;
  VALUE v99fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v100ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v101ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v102ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v103ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v104ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v105ffff  1='(1) CMHC, Mental Health Institute'
                  2='(2) Hospital (general, state and mental)'
                  3='(3) Social/community agencies'
                  4='(4) Local, county government agencies' 5='(5) Advocacy agencies'
                  6='(6) Planning agencies' 7='(7) Other (undefined agencies)'
                  9='(9) N/A' ;
  VALUE v106ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v107ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v108ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v109ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v110ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v111ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v112ffff  1='(1) CMHC, Mental Health Institute'
                  2='(2) Hospital (general, state and mental)'
                  3='(3) Social/community agencies'
                  4='(4) Local, county government agencies' 5='(5) Advocacy agencies'
                  6='(6) Planning agencies' 7='(7) Other (undefined agencies)'
                  9='(9) N/A' ;
  VALUE v113ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v114ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v115ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v116ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v117ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v118ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v119ffff  1='(1) CMHC, Mental Health Institute'
                  2='(2) Hospital (general, state and mental)'
                  3='(3) Social/community agencies'
                  4='(4) Local, county government agencies' 5='(5) Advocacy agencies'
                  6='(6) Planning agencies' 7='(7) Other (undefined agencies)'
                  9='(9) N/A' ;
  VALUE v120ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v121ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v122ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v123ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v124ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v125ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v126ffff  1='(1) CMHC, Mental Health Institute'
                  2='(2) Hospital (general, state and mental)'
                  3='(3) Social/community agencies'
                  4='(4) Local, county government agencies' 5='(5) Advocacy agencies'
                  6='(6) Planning agencies' 7='(7) Other (undefined agencies)'
                  9='(9) N/A' ;
  VALUE v127ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v128ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v129ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v130ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v131ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v132ffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=171;
INPUT
        CASEID 1-3              V5 4-5                  V6 6
        V7 7-9                  V8 10-11                V9 12
        V10 13-17               V11 18-21               V12 22-23
        V13 24-26               V14 27-29               V15 30-31
        V16 32-34               V17 35-37               V18 38-40
        V19 41-43               V20 44                  V21 45-47
        V22 48-50               V23 51-53               V24 54-56
        V25 57-59               V26 60-62               V27 63-65
        V28 66                  V29 67                  V30 68
        V31 69                  V32 70                  V33 71
        V34 72                  V35 73                  V36 74
        V37 75                  V38 76                  V39 77
        V40 78                  V41 79                  V42 80
        V43 81                  V44 82                  V45 83
        V46 84                  V47 85                  V48 86
        V49 87                  V50 88                  V51 89
        V52 90                  V53 91                  V54 92
        V55 93                  V56 94                  V57 95
        V58 96                  V59 97                  V60 98
        V61 99                  V62 100                 V63 101
        V64 102                 V65 103                 V66 104
        V67 105                 V68 106                 V69 107-108
        V70 109                 V71 110                 V72 111
        V73 112                 V74 113                 V75 114
        V76 115                 V77 116                 V78 117
        V79 118                 V80 119                 V81 120
        V82 121                 V83 122                 V84 123
        V85 124                 V86 125                 V87 126
        V88 127                 V89 128                 V90 129
        V91 130                 V92 131                 V93 132
        V94 133                 V95 134                 V96 135
        V97 136                 V98 137                 V99 138
        V100 139                V101 140                V102 141
        V103 142                V104 143                V105 144
        V106 145                V107 146                V108 147
        V109 148                V110 149                V111 150
        V112 151                V113 152                V114 153
        V115 154                V116 155                V117 156
        V118 157                V119 158                V120 159
        V121 160                V122 161                V123 162
        V124 163                V125 164                V126 165
        V127 166                V128 167                V129 168
        V130 169                V131 170                V132 171
        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'ICPSR SEQUENTIAL CASE ID'
   V5      = 'STCODE'
   V6      = 'SRVCODE'
   V7      = 'AGENCY'
   V8      = 'YRS'
   V9      = 'AAAOP'
   V10     = 'BUDGET'
   V11     = 'MATCH'
   V12     = 'TIIIMHS'
   V13     = 'SPFT'
   V14     = 'SPPT'
   V15     = 'SSFT'
   V16     = 'SSPT'
   V17     = 'VOL'
   V18     = 'GRDGE'
   V19     = 'SEMWKSP'
   V20     = 'SUATCAS'
   V21     = 'RFNUT'
   V22     = 'RFMED'
   V23     = 'RFSC'
   V24     = 'RFMH'
   V25     = 'RFTRNS'
   V26     = 'RFJJ'
   V27     = 'RFOT'
   V28     = 'HSAPC'
   V29     = 'HSAGB'
   V30     = 'CMHCGB'
   V31     = 'MHINPAB'
   V32     = 'FREQCON'
   V33     = 'CHARMHP'
   V34     = 'CHARAP'
   V35     = 'PPMH'
   V36     = 'POSINAC'
   V37     = 'PRINC'
   V38     = 'PRTRNS'
   V39     = 'PRNUT'
   V40     = 'PRMH'
   V41     = 'PRPH'
   V42     = 'PRHOUS'
   V43     = 'SPTSYP'
   V44     = 'POLAWR'
   V45     = 'GVTRESP'
   V46     = 'MECHINF'
   V47     = 'STFCHARA'
   V48     = 'STFCHARB'
   V49     = 'STFCHARC'
   V50     = 'ECOFACA'
   V51     = 'ECOFACB'
   V52     = 'ECOFACC'
   V53     = 'POLFACA'
   V54     = 'POLFACB'
   V55     = 'POLFACC'
   V56     = 'SYSFACA'
   V57     = 'SYSFACB'
   V58     = 'SYSFACC'
   V59     = 'SOCISSA'
   V60     = 'SOCISSB'
   V61     = 'SOCISSC'
   V62     = 'V2018'
   V63     = 'V2323'
   V64     = 'V2222'
   V65     = 'V2525'
   V66     = 'V1414'
   V67     = 'V1516'
   V68     = 'V1617'
   V69     = 'NUMLISTD'
   V70     = 'CLASS'
   V71     = 'A1'
   V72     = 'B1'
   V73     = 'C1'
   V74     = 'D1'
   V75     = 'E1'
   V76     = '/F1'
   V77     = 'Class 2'
   V78     = 'A2'
   V79     = 'B2'
   V80     = 'C2'
   V81     = 'D2'
   V82     = 'E2'
   V83     = 'F2'
   V84     = 'CLASS 3'
   V85     = 'A3'
   V86     = 'B3'
   V87     = 'C3'
   V88     = 'D3'
   V89     = 'E3'
   V90     = 'F3'
   V91     = 'CLASS 4'
   V92     = 'A4'
   V93     = 'B4'
   V94     = 'C4'
   V95     = 'D4'
   V96     = 'E4'
   V97     = 'F4'
   V98     = 'CLASS 5'
   V99     = 'A5'
   V100    = 'B5'
   V101    = 'C5'
   V102    = 'D5'
   V103    = 'E5'
   V104    = 'F5'
   V105    = 'CLASS 6'
   V106    = 'A6'
   V107    = 'B6'
   V108    = 'C6'
   V109    = 'D6'
   V110    = 'E6'
   V111    = 'F6'
   V112    = 'CLASS 7'
   V113    = 'A7'
   V114    = 'B7'
   V115    = 'C7'
   V116    = 'D7'
   V117    = 'E7'
   V118    = 'F7'
   V119    = 'CLASS 8'
   V120    = 'A8'
   V121    = 'B8'
   V122    = 'C8'
   V123    = 'D8'
   V124    = 'E8'
   V125    = 'F8'
   V126    = 'CLASS 9'
   V127    = 'A9'
   V128    = 'B9'
   V129    = 'C9'
   V130    = 'D9'
   V131    = 'E9'
   V132    = 'F9'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (V8 = 99) THEN V8 = .;
   IF (V9 = 9) THEN V9 = .;
   IF (V10 = 99999) THEN V10 = .;
   IF (V11 = 9999) THEN V11 = .;
   IF (V12 = 99) THEN V12 = .;
   IF (V13 = 999) THEN V13 = .;
   IF (V14 = 999) THEN V14 = .;
   IF (V15 = 99) THEN V15 = .;
   IF (V16 = 999) THEN V16 = .;
   IF (V17 = 999) THEN V17 = .;
   IF (V18 = 999) THEN V18 = .;
   IF (V19 = 999) THEN V19 = .;
   IF (V20 = 9) THEN V20 = .;
   IF (V21 = 999) THEN V21 = .;
   IF (V22 = 999) THEN V22 = .;
   IF (V23 = 999) THEN V23 = .;
   IF (V24 = 999) THEN V24 = .;
   IF (V25 = 999) THEN V25 = .;
   IF (V26 = 999) THEN V26 = .;
   IF (V27 = 999) THEN V27 = .;
   IF (V28 = 9) THEN V28 = .;
   IF (V29 = 9) THEN V29 = .;
   IF (V30 = 9) THEN V30 = .;
   IF (V31 = 9) THEN V31 = .;
   IF (V32 = 9) THEN V32 = .;
   IF (V33 = 9) THEN V33 = .;
   IF (V34 = 9) THEN V34 = .;
   IF (V35 = 9) THEN V35 = .;
   IF (V36 = 9) THEN V36 = .;
   IF (V37 = 9) THEN V37 = .;
   IF (V38 = 9) THEN V38 = .;
   IF (V39 = 9) THEN V39 = .;
   IF (V40 = 9) THEN V40 = .;
   IF (V41 = 9) THEN V41 = .;
   IF (V42 = 9) THEN V42 = .;
   IF (V43 = 9) THEN V43 = .;
   IF (V44 = 9) THEN V44 = .;
   IF (V45 = 9) THEN V45 = .;
   IF (V46 = 9) THEN V46 = .;
   IF (V47 = 9) THEN V47 = .;
   IF (V48 = 9) THEN V48 = .;
   IF (V49 = 9) THEN V49 = .;
   IF (V50 = 9) THEN V50 = .;
   IF (V51 = 9) THEN V51 = .;
   IF (V52 = 9) THEN V52 = .;
   IF (V53 = 9) THEN V53 = .;
   IF (V54 = 9) THEN V54 = .;
   IF (V55 = 9) THEN V55 = .;
   IF (V56 = 9) THEN V56 = .;
   IF (V57 = 9) THEN V57 = .;
   IF (V58 = 9) THEN V58 = .;
   IF (V59 = 9) THEN V59 = .;
   IF (V60 = 9) THEN V60 = .;
   IF (V61 = 9) THEN V61 = .;
   IF (V62 = 9) THEN V62 = .;
   IF (V63 = 9) THEN V63 = .;
   IF (V64 = 9) THEN V64 = .;
   IF (V65 = 9) THEN V65 = .;
   IF (V66 = 9) THEN V66 = .;
   IF (V67 = 9) THEN V67 = .;
   IF (V68 = 9) THEN V68 = .;
   IF (V69 = 99) THEN V69 = .;
   IF (V70 = 9) THEN V70 = .;
   IF (V71 = 9) THEN V71 = .;
   IF (V72 = 9) THEN V72 = .;
   IF (V73 = 9) THEN V73 = .;
   IF (V74 = 9) THEN V74 = .;
   IF (V75 = 9) THEN V75 = .;
   IF (V76 = 9) THEN V76 = .;
   IF (V77 = 9) THEN V77 = .;
   IF (V78 = 9) THEN V78 = .;
   IF (V79 = 9) THEN V79 = .;
   IF (V80 = 9) THEN V80 = .;
   IF (V81 = 9) THEN V81 = .;
   IF (V82 = 9) THEN V82 = .;
   IF (V83 = 9) THEN V83 = .;
   IF (V84 = 9) THEN V84 = .;
   IF (V85 = 9) THEN V85 = .;
   IF (V86 = 9) THEN V86 = .;
   IF (V87 = 9) THEN V87 = .;
   IF (V88 = 9) THEN V88 = .;
   IF (V89 = 9) THEN V89 = .;
   IF (V90 = 9) THEN V90 = .;
   IF (V91 = 9) THEN V91 = .;
   IF (V92 = 9) THEN V92 = .;
   IF (V93 = 9) THEN V93 = .;
   IF (V94 = 9) THEN V94 = .;
   IF (V95 = 9) THEN V95 = .;
   IF (V96 = 9) THEN V96 = .;
   IF (V97 = 9) THEN V97 = .;
   IF (V98 = 9) THEN V98 = .;
   IF (V99 = 9) THEN V99 = .;
   IF (V100 = 9) THEN V100 = .;
   IF (V101 = 9) THEN V101 = .;
   IF (V102 = 9) THEN V102 = .;
   IF (V103 = 9) THEN V103 = .;
   IF (V104 = 9) THEN V104 = .;
   IF (V105 = 9) THEN V105 = .;
   IF (V106 = 9) THEN V106 = .;
   IF (V107 = 9) THEN V107 = .;
   IF (V108 = 9) THEN V108 = .;
   IF (V109 = 9) THEN V109 = .;
   IF (V110 = 9) THEN V110 = .;
   IF (V111 = 9) THEN V111 = .;
   IF (V112 = 9) THEN V112 = .;
   IF (V113 = 9) THEN V113 = .;
   IF (V114 = 9) THEN V114 = .;
   IF (V115 = 9) THEN V115 = .;
   IF (V116 = 9) THEN V116 = .;
   IF (V117 = 9) THEN V117 = .;
   IF (V118 = 9) THEN V118 = .;
   IF (V119 = 9) THEN V119 = .;
   IF (V120 = 9) THEN V120 = .;
   IF (V121 = 9) THEN V121 = .;
   IF (V122 = 9) THEN V122 = .;
   IF (V123 = 9) THEN V123 = .;
   IF (V124 = 9) THEN V124 = .;
   IF (V125 = 9) THEN V125 = .;
   IF (V126 = 9) THEN V126 = .;
   IF (V127 = 9) THEN V127 = .;
   IF (V128 = 9) THEN V128 = .;
   IF (V129 = 9) THEN V129 = .;
   IF (V130 = 9) THEN V130 = .;
   IF (V131 = 9) THEN V131 = .;
   IF (V132 = 9) THEN V132 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CASEID caseid. V5 v5ffffff. V6 v6ffffff.
         V7 v7ffffff. V8 v8ffffff. V9 v9ffffff.
         V10 v10fffff. V11 v11fffff. V12 v12fffff.
         V13 v13fffff. V14 v14fffff. V15 v15fffff.
         V16 v16fffff. V17 v17fffff. V18 v18fffff.
         V19 v19fffff. V20 v20fffff. V21 v21fffff.
         V22 v22fffff. V23 v23fffff. V24 v24fffff.
         V25 v25fffff. V26 v26fffff. V27 v27fffff.
         V28 v28fffff. V29 v29fffff. V30 v30fffff.
         V31 v31fffff. V32 v32fffff. V33 v33fffff.
         V34 v34fffff. V35 v35fffff. V36 v36fffff.
         V37 v37fffff. V38 v38fffff. V39 v39fffff.
         V40 v40fffff. V41 v41fffff. V42 v42fffff.
         V43 v43fffff. V44 v44fffff. V45 v45fffff.
         V46 v46fffff. V47 v47fffff. V48 v48fffff.
         V49 v49fffff. V50 v50fffff. V51 v51fffff.
         V52 v52fffff. V53 v53fffff. V54 v54fffff.
         V55 v55fffff. V56 v56fffff. V57 v57fffff.
         V58 v58fffff. V59 v59fffff. V60 v60fffff.
         V61 v61fffff. V62 v62fffff. V63 v63fffff.
         V64 v64fffff. V65 v65fffff. V66 v66fffff.
         V67 v67fffff. V68 v68fffff. V69 v69fffff.
         V70 v70fffff. V71 v71fffff. V72 v72fffff.
         V73 v73fffff. V74 v74fffff. V75 v75fffff.
         V76 v76fffff. V77 v77fffff. V78 v78fffff.
         V79 v79fffff. V80 v80fffff. V81 v81fffff.
         V82 v82fffff. V83 v83fffff. V84 v84fffff.
         V85 v85fffff. V86 v86fffff. V87 v87fffff.
         V88 v88fffff. V89 v89fffff. V90 v90fffff.
         V91 v91fffff. V92 v92fffff. V93 v93fffff.
         V94 v94fffff. V95 v95fffff. V96 v96fffff.
         V97 v97fffff. V98 v98fffff. V99 v99fffff.
         V100 v100ffff. V101 v101ffff. V102 v102ffff.
         V103 v103ffff. V104 v104ffff. V105 v105ffff.
         V106 v106ffff. V107 v107ffff. V108 v108ffff.
         V109 v109ffff. V110 v110ffff. V111 v111ffff.
         V112 v112ffff. V113 v113ffff. V114 v114ffff.
         V115 v115ffff. V116 v116ffff. V117 v117ffff.
         V118 v118ffff. V119 v119ffff. V120 v120ffff.
         V121 v121ffff. V122 v122ffff. V123 v123ffff.
         V124 v124ffff. V125 v125ffff. V126 v126ffff.
         V127 v127ffff. V128 v128ffff. V129 v129ffff.
         V130 v130ffff. V131 v131ffff. V132 v132ffff.
          ;
*/

RUN ;
